@@ -88,9 +88,9 @@ class Data_inegrator:
                     klb=klb_coefficient))
 
             # Construct the models according to the current configuration
-            xy_vae = StandardVAE(self.xy_architecture + [latent_layer_size], self.activation_fn)
-            x_vae = StandardVAE(self.x_architecture + [latent_layer_size], self.activation_fn)
-            y_vae = StandardVAE(self.y_architecture + [latent_layer_size], self.activation_fn)
+            xy_vae = StandardVAE(self.xy_architecture + latent_layer_size, self.activation_fn)
+            x_vae = StandardVAE(self.x_architecture + latent_layer_size, self.activation_fn)
+            y_vae = StandardVAE(self.y_architecture + latent_layer_size, self.activation_fn)
             # Create the full VAE based on the standardVAE's above.
             full_vae = MultipleVAE(xy_vae, x_vae, y_vae)
             optimizer = self.optimizer(full_vae.parameters(), lr=learning_rate)
@@ -137,12 +137,36 @@ class Data_inegrator:
                         best_model_loss = float(average_validation_sample_loss)
                     # keep tracking of the validation loss in every epoch.
                     average_validation_sample_loss_per_epoch.append(average_validation_sample_loss)
-                    stop = early_stopping(average_validation_sample_loss_per_epoch, patience=self.patience, ascending=False)
+                    stop = early_stopping(average_validation_sample_loss_per_epoch, patience=self.patience,
+                                          ascending=False)
             configuration_best_result = min(average_validation_sample_loss_per_epoch)
             print('The model best loss achieved on the validation set is : {}  '.format(configuration_best_result))
             best_results_of_each_configuration.append(configuration)
 
         configuration_results_df = pd.DataFrame(self.configuration_list)
-        configuration_results_df=configuration_results_df.assign(best_loss=best_results_of_each_configuration)
-        configuration_results_df.to_csv(os.path.join(self.results_path,'models_results.csv'))
+        configuration_results_df = configuration_results_df.assign(best_loss=best_results_of_each_configuration)
+        configuration_results_df.to_csv(os.path.join(self.results_path, 'models_results.csv'))
 
+
+    def project_all_data(self):
+        latent_representation_list = []
+        patient_id_list = []
+        self.patients_dataset.dict_retrieval_flag = 0
+        full_vae = torch.load(os.path.join(self.results_path, 'best_model.pt'))
+
+        with torch.no_grad():
+            full_vae.eval()
+            for patient in self.patients_dataset:
+                if patient.get_status() == 0:
+                    field0, field1 = patient.field0, patient.field1
+                    latent_representation = full_vae.xyvae(torch.cat([field0, field1], dim=0))[4]
+                elif patient.get_status() == 1:
+                    field0 = patient.field0
+                    latent_representation = full_vae.xvae(field0)[4]
+                else:
+                    field1 = patient.field1
+                    latent_representation = full_vae.yvae(field1)[4]
+                latent_representation_list.append(latent_representation.numpy())
+                patient_id_list.append(patient.id)
+            latent_representation_df = pd.DataFrame(data=latent_representation_list, index=patient_id_list)
+            latent_representation_df.to_csv(os.path.join(self.results_path, 'latent_representation.csv'))
